/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer *
* Copyright (C) 2021 Renesas Electronics Corporation. All rights reserved.    
*******************************************************************************/
/*******************************************************************************
* File Name    : r_hs3001.h
* Version      : 1.0
* Description  : Device driver for Renesas Sensor HS3001.
*              : (Relative humidity, Temperature)
******************************************************************************/
/*****************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 26.02.2021 1.00     First Release
******************************************************************************/

#ifndef HS3001_H
#define HS3001_H

/******************************************************************************
Exported global variables
******************************************************************************/

/******************************************************************************
Macro definitions
******************************************************************************/

/* HS3001 Device Slave Address */
#define HS3001_ADDR                     (0x44<<1)               /* HS3001 Device Slave Address */

/* HS3001 Commands */
#define HS3001_CMD_MR                   (HS3001_ADDR | 0x00)    /* Measurement Requests (MR) */
#define HS3001_CMD_DF                   (HS3001_ADDR | 0x01)    /* Data Fetch           (DF) */

#define HS3001_DENOMINATOR              (0x4000 - 1)            /* 2^14 - 1 */

#define HS3001_MEASUREMENT_TIME         (40)                    /* Measurement time for 14bit resolution */

/* Error status */
typedef enum hs3001_status {
    HS3001_STATUS_OK                    = 0,
    HS3001_STATUS_I2C_TRANSFER_ERROR    = 1,
    HS3001_STATUS_ERROR                 = 2
} hs3001_status_t;

typedef struct hs3001_sensor_data {
    uint8_t h_integer;
    uint8_t h_decimal;
    uint8_t t_integer;
    uint8_t t_decimal;
} hs3001_sensor_data_t;
    
/******************************************************************************
Exported global functions (to be accessed by other files)
******************************************************************************/

void            R_HS3001_Init(void);
hs3001_status_t R_HS3001_Measurement(hs3001_sensor_data_t *sd);

#endif /* HS3001_H */
