/**
 ****************************************************************************************
 *
 * @file		db_handle.h
 *
 * @brief	Definition of Database Handle for Profile
 *
 * Copyright(C) 2013-2014 Renesas Electronics Corporation
 *
 * $Rev: 6019 $
 *
 ****************************************************************************************
 */


#ifndef _DB_HANDLE_H_
#define _DB_HANDLE_H_

#include "prf_sel.h"

/**
 * TYPE DEFINES
 ****************************************************************************************
 */

#define HID_BOOT_OTHER					0u
#define HID_BOOT_KB						1u
#define HID_BOOT_MO						2u

#define HIDS_INST1						HID_BOOT_KB
#define HIDS_INST2						HID_BOOT_MO

/** Attribute database handles */
enum
{
	/* Generic Access Profile Service*/
	GAP_HDL_PRIM_SVC = 0x0001,
	GAP_HDL_CHAR_DEVNAME,
	GAP_HDL_DEVNAME,
	GAP_HDL_CHAR_ICON,
	GAP_HDL_ICON,
	GAP_HDL_CHAR_SLAVE_PREF_PARAM,
	GAP_HDL_SLAVE_PREF_PARAM,

	/* Generic Attribute Profile Service */
	GATT_HDL_PRIM_SVC,
	GATT_HDL_CHAR_SVC_CHANGED,
	GATT_HDL_SVC_CHANGED,
	GATT_HDL_SVC_CHANGED_IND_CFG,

	#if defined(USE_FW_UPDATE_PROFILE)
	FWUS_HDL_SVC,
	FWUS_HDL_DATA_CNTL_CHAR,
	FWUS_HDL_DATA_CNTL_VAL,
	FWUS_HDL_DATA_CHAR,
	FWUS_HDL_DATA_VAL,
	#endif
	
	#if (USE_LINK_LOSS_SERVICE)
	/* Link Loss Service */
	LLS_HDL_PRIM_SVC,
	LLS_HDL_ALERT_LVL_CHAR,
	LLS_HDL_ALERT_LVL_VAL,
	#endif /* #if (USE_LINK_LOSS_SERVICE) */
	#if (USE_TX_POWER_SERVICE)
    /* TX Power Service */
	TPS_HDL_PRIM_SVC,
	TPS_HDL_TXPW_LVL_CHAR,
	TPS_HDL_TXPW_LVL_VAL,
	#endif /* #if (USE_TX_POWER_SERVICE) */

	#if (USE_IMMEDIATE_ALERT_SERVICE)
	/* Immediate Alert Service */
	IAS_HDL_PRIM_SVC,
	IAS_HDL_ALERT_LVL_CHAR,
	IAS_HDL_ALERT_LVL_VAL,
	#endif /* #if (USE_IMMEDIATE_ALERT_SERVICE) */

	#if (PRF_SEL_HTPT)
	/* Health Thermometer Service */
	HTS_HDL_SVC,
	HTS_HDL_TEMP_MEAS_CHAR,
	HTS_HDL_TEMP_MEAS_VAL,
	HTS_HDL_TEMP_MEAS_IND_CFG,
	HTS_HDL_TEMP_TYPE_CHAR,
	HTS_HDL_TEMP_TYPE_VAL,
	HTS_HDL_INTERM_TEMP_CHAR,
	HTS_HDL_INTERM_TEMP_VAL,
	HTS_HDL_INTERM_TEMP_CFG,
	HTS_HDL_MEAS_INTV_CHAR,
	HTS_HDL_MEAS_INTV_VAL,
	HTS_HDL_MEAS_INTV_CFG,
	HTS_HDL_MEAS_INTV_RANGE_VAL,
	#endif /* #if (PRF_SEL_HTPT) */

	#if (PRF_SEL_BLPS)
	/* Blood Pressure Service */
	BLS_HDL_SVC,
	BLS_HDL_BLDPRS_MEAS_CHAR,
	BLS_HDL_BLDPRS_MEAS_VAL,
	BLS_HDL_BLDPRS_MEAS_IND_CFG,
	BLS_HDL_INTERM_CUFPRS_CHAR,
	BLS_HDL_INTERM_CUFPRS_VAL,
	BLS_HDL_INTERM_CUFPRS_CFG,
	BLS_HDL_BLDPRS_FEAT_CHAR,
	BLS_HDL_BLDPRS_FEAT_VAL,
	#endif /* #if (PRF_SEL_BLPS) */

	#if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP)
	/* Device information service */
	DIS_HDL_SVC,
	#if (USE_DEV_INFO_SERVICE)
	DIS_HDL_SYS_ID_CHAR,
	DIS_HDL_SYS_ID_VAL,
	DIS_HDL_MODEL_NB_CHAR,
	DIS_HDL_MODEL_NB_VAL,
	DIS_HDL_SERIAL_NB_CHAR,
	DIS_HDL_SERIAL_NB_VAL,
	DIS_HDL_FW_REV_CHAR,
	DIS_HDL_FW_REV_VAL,
	DIS_HDL_HW_REV_CHAR,
	DIS_HDL_HW_REV_VAL,
	DIS_HDL_SW_REV_CHAR,
	DIS_HDL_SW_REV_VAL,
	DIS_HDL_MANUF_NAME_CHAR,
	DIS_HDL_MANUF_NAME_VAL,
	DIS_HDL_IEEE_CERTIF_CHAR,
	DIS_HDL_IEEE_CERTIF_VAL,
	#endif /* #if (USE_DEV_INFO_SERVICE) */
	#if (USE_DEV_INFO_SERVICE_PNP)
	DIS_HDL_PNP_ID_CHAR,
	DIS_HDL_PNP_ID_VAL,
	#endif /* #if (USE_DEV_INFO_SERVICE_PNP) */
	#endif /* #if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP) */

	#if (PRF_SEL_HGHD)
	/* HID Service */
	HIDS1_HDL_SVC,
	HIDS1_HDL_INCLUDE_SVC,
	HIDS1_HDL_PROTOCOL_MD_CHAR,
	HIDS1_HDL_PROTOCOL_MD_VAL,
	HIDS1_HDL_REPORT_INPUT_CHAR,
	HIDS1_HDL_REPORT_INPUT_VAL,
	HIDS1_HDL_REPORT_INPUT_CFG,
	HIDS1_HDL_INPUT_REP_REF,
	HIDS1_HDL_REPORT_OUTPUT_CHAR,
	HIDS1_HDL_REPORT_OUTPUT_VAL,
	HIDS1_HDL_OUTPUT_REP_REF,
	HIDS1_HDL_REPORT_FEATURE_CHAR,
	HIDS1_HDL_REPORT_FEATURE_VAL,
	HIDS1_HDL_FEATURE_REP_REF,
	HIDS1_HDL_REPORT_MAP_CHAR,
	HIDS1_HDL_REPORT_MAP_VAL,
	HIDS1_HDL_EXTERNAL_REP_REF,
	#if (HIDS_INST1 == HID_BOOT_KB)
	HIDS1_HDL_BOOTKB_INPUT_CHAR,
	HIDS1_HDL_BOOTKB_INPUT_VAL,
	HIDS1_HDL_BOOTKB_INPUT_CFG,
	HIDS1_HDL_BOOTKB_OUTPUT_CHAR,
	HIDS1_HDL_BOOTKB_OUTPUT_VAL,
	#elif (HIDS_INST1 == HID_BOOT_MO)
	HIDS1_HDL_BOOTMO_INPUT_CHAR,
	HIDS1_HDL_BOOTMO_INPUT_VAL,
	HIDS1_HDL_BOOTMO_INPUT_CFG,
	#endif
	HIDS1_HDL_HID_INFO_CHAR,
	HIDS1_HDL_HID_INFO_VAL,
	HIDS1_HDL_HID_CP_CHAR,
	HIDS1_HDL_HID_CP_VAL,
	#ifdef HID_MULTI_INSTANCE
	HIDS2_HDL_SVC,
	HIDS2_HDL_INCLUDE_SVC,
	HIDS2_HDL_PROTOCOL_MD_CHAR,
	HIDS2_HDL_PROTOCOL_MD_VAL,
	HIDS2_HDL_REPORT_INPUT_CHAR,
	HIDS2_HDL_REPORT_INPUT_VAL,
	HIDS2_HDL_REPORT_INPUT_CFG,
	HIDS2_HDL_INPUT_REP_REF,
	HIDS2_HDL_REPORT_OUTPUT_CHAR,
	HIDS2_HDL_REPORT_OUTPUT_VAL,
	HIDS2_HDL_OUTPUT_REP_REF,
	HIDS2_HDL_REPORT_FEATURE_CHAR,
	HIDS2_HDL_REPORT_FEATURE_VAL,
	HIDS2_HDL_FEATURE_REP_REF,
	HIDS2_HDL_REPORT_MAP_CHAR,
	HIDS2_HDL_REPORT_MAP_VAL,
	HIDS2_HDL_EXTERNAL_REP_REF,
	#if (HIDS_INST2 == HID_BOOT_KB)
	HIDS2_HDL_BOOTKB_INPUT_CHAR,
	HIDS2_HDL_BOOTKB_INPUT_VAL,
	HIDS2_HDL_BOOTKB_INPUT_CFG,
	HIDS2_HDL_BOOTKB_OUTPUT_CHAR,
	HIDS2_HDL_BOOTKB_OUTPUT_VAL,
	#elif (HIDS_INST2 == HID_BOOT_MO)
	HIDS2_HDL_BOOTMO_INPUT_CHAR,
	HIDS2_HDL_BOOTMO_INPUT_VAL,
	HIDS2_HDL_BOOTMO_INPUT_CFG,
	#endif
	HIDS2_HDL_HID_INFO_CHAR,
	HIDS2_HDL_HID_INFO_VAL,
	HIDS2_HDL_HID_CP_CHAR,
	HIDS2_HDL_HID_CP_VAL,
	#endif /* #ifdef HID_MULTI_INSTANCE */
	#endif /* #if (PRF_SEL_HGHD) */

	#if (USE_BATTERY_SERVICE)
	/* Battery Service */
	BAS1_HDL_SVC,
	BAS1_HDL_BATTERY_LVL_CHAR,
	BAS1_HDL_BATTERY_LVL_VAL,
	BAS1_HDL_BATTERY_LVL_CFG,
	BAS1_HDL_CHAR_PRESEN_FMT,
	#if (PRF_SEL_HGHD)
	BAS1_HDL_BATT_REP_REF,
	#endif /* #if (PRF_SEL_HGHD) */
	#ifdef HID_MULTI_INSTANCE
	BAS2_HDL_SVC,
	BAS2_HDL_BATTERY_LVL_CHAR,
	BAS2_HDL_BATTERY_LVL_VAL,
	BAS2_HDL_BATTERY_LVL_CFG,
	BAS2_HDL_CHAR_PRESEN_FMT,
	#if (PRF_SEL_HGHD)
	BAS2_HDL_BATT_REP_REF,
	#endif /* #if (PRF_SEL_HGHD) */
	#endif /* #ifdef HID_MULTI_INSTANCE */
	#endif /* #if (USE_BATTERY_SERVICE) */

	#if (USE_SCAN_PARAMETER_SERVICE)
	/* Scan Parameters Service */
	SCANS_HDL_SVC,
	SCANS_HDL_INTV_WINDOW_CHAR,
	SCANS_HDL_INTV_WINDOW_VAL,
	SCANS_HDL_REFRESH_CHAR,
	SCANS_HDL_REFRESH_VAL,
	SCANS_HDL_REFRESH_CFG,
	#endif /* #if (USE_SCAN_PARAMETER_SERVICE) */

	#if (PRF_SEL_HRPS)
	/* Heart Rate Service */
	HRS_HDL_SVC,
	HRS_HDL_HRTRATE_MEAS_CHAR,
	HRS_HDL_HRTRATE_MEAS_VAL,
	HRS_HDL_HRTRATE_MEAS_NTF_CFG,
	HRS_HDL_HRTRATE_BSL_CHAR,
	HRS_HDL_HRTRATE_BSL_VAL,
	HRS_HDL_HRTRATE_CP_CHAR,
	HRS_HDL_HRTRATE_CP_VAL,
	#endif /* #if (PRF_SEL_HRPS) */

	#if (PRF_SEL_CSCS)
	/* Cycling Speed and Cadence Service */
	CSCS_HDL_SVC,
	CSCS_HDL_CSC_MEAS_CHAR,
	CSCS_HDL_CSC_MEAS_VAL,
	CSCS_HDL_CSC_MEAS_NTF_CFG,
	CSCS_HDL_CSC_FEATURE_CHAR,
	CSCS_HDL_CSC_FEATURE_VAL,
	CSCS_HDL_SENSOR_LOC_CHAR,
	CSCS_HDL_SENSOR_LOC_VAL,
	CSCS_HDL_SC_CP_CHAR,
	CSCS_HDL_SC_CP_VAL,
	CSCS_HDL_SC_CP_IND_CFG,
	#endif /* #if (PRF_SEL_CSCS) */

	#if (PRF_SEL_GLPS)
	/* Glucose Service */
	GLS_HDL_SVC,
	GLS_HDL_GL_MEAS_CHAR,
	GLS_HDL_GL_MEAS_VAL,
	GLS_HDL_GL_MEAS_NTF_CFG,
	GLS_HDL_GL_MEAS_CONTEXT_CHAR,
	GLS_HDL_GL_MEAS_CONTEXT_VAL,
	GLS_HDL_GL_MEAS_CONTEXT_NTF_CFG,
	GLS_HDL_GL_FEATURE_CHAR,
	GLS_HDL_GL_FEATURE_VAL,
	GLS_HDL_RA_CP_CHAR,
	GLS_HDL_RA_CP_VAL,
	GLS_HDL_RA_CP_IND_CFG,
	#endif /* #if (PRF_SEL_GLPS) */

	#if (PRF_SEL_CPPS)
	CPS_HDL_SVC,
	CPS_HDL_MEAS_CHAR,
	CPS_HDL_MEAS_VAL,
	CPS_HDL_MEAS_NTF_CFG,
	CPS_HDL_MEAS_BRD_CFG,
	CPS_HDL_FEATURE_CHAR,
	CPS_HDL_FEATURE_VAL,
	CPS_HDL_SENSOR_LOCATION_CHAR,
	CPS_HDL_SENSOR_LOCATION_VAL,
	CPS_HDL_VECTOR_CHAR,
	CPS_HDL_VECTOR_VAL,
	CPS_HDL_VECTOR_NTF_CFG,
	CPS_HDL_CP_CHAR,
	CPS_HDL_CP_VAL,
	CPS_HDL_CP_IND_CFG,
	#endif /* #if (PRF_SEL_CPPS) */
	
	#if (PRF_SEL_TIPS)
	/* Current Time Service */
	CTS_HDL_SVC,
	CTS_HDL_CURRENT_TIME_CHAR,
	CTS_HDL_CURRENT_TIME_VAL,
	CTS_HDL_CURRENT_TIME_NTF_CFG,
	CTS_HDL_LOCAL_TIME_CHAR,
	CTS_HDL_LOCAL_TIME_VAL,
	CTS_HDL_REF_TIME_CHAR,
	CTS_HDL_REF_TIME_VAL,

	/* Next DST Change Service */
	NDCS_HDL_SVC,
	NDCS_HDL_TIME_DST_CHAR,
	NDCS_HDL_TIME_DST_VAL,

	/* Reference Time Update Service */
	RTUS_HDL_SVC,
	RTUS_HDL_TIME_UPDATE_CP_CHAR,
	RTUS_HDL_TIME_UPDATE_CP_VAL,
	RTUS_HDL_TIME_UPDATE_STATE_CHAR,
	RTUS_HDL_TIME_UPDATE_STATE_VAL,
	#endif /* #if (PRF_SEL_TIPS) */

	#if (PRF_SEL_ANPS)
	/* Alert Notifisation Service */
	ANPS_HDL_SVC,
	ANPS_HDL_SUPP_NEW_AL_CATEGORY_CHAR,
	ANPS_HDL_SUPP_NEW_AL_CATEGORY_VAL,
	ANPS_HDL_NEW_ALERT_CHAR,
	ANPS_HDL_NEW_ALERT_VAL,
	ANPS_HDL_NEW_ALERT_CFG,
	ANPS_HDL_SUPP_UNREAD_CATEGORY_CHAR,
	ANPS_HDL_SUPP_UNREAD_CATEGORY_VAL,
	ANPS_HDL_UNREAD_ALERT_STATUS_CHAR,
	ANPS_HDL_UNREAD_ALERT_STATUS_VAL,
	ANPS_HDL_UNREAD_ALERT_STATUS_CFG,
	ANPS_HDL_AL_NTF_CTRL_POINT_CHAR,
	ANPS_HDL_AL_NTF_CTRL_POINT_VAL,
	#endif /* #if (PRF_SEL_ANPS) */

	#if (PRF_SEL_LNPS)
	/* Location and Navigation Service */
	LNS_HDL_SVC,
	LNS_HDL_LN_FEATURE_CHAR,
	LNS_HDL_LN_FEATURE_VAL,
	LNS_HDL_LOC_SPD_CHAR,
	LNS_HDL_LOC_SPD_VAL,
	LNS_HDL_LOC_SPD_NTF_CFG,
	LNS_HDL_POS_QUALITY_CHAR,
	LNS_HDL_POS_QUALITY_VAL,
	LNS_HDL_LN_CP_CHAR,
	LNS_HDL_LN_CP_VAL,
	LNS_HDL_LN_CP_IND_CFG,
	LNS_HDL_NAVI_CHAR,
	LNS_HDL_NAVI_VAL,
	LNS_HDL_NAVI_NTF_CFG,
	#endif /* #if (PRF_SEL_LNPS) */
	
	#if (PRF_SEL_PASS)
	/* Phone Alert Status Service */
	PASS_HDL_SVC,
	PASS_HDL_ALERT_STATUS_CHAR,
	PASS_HDL_ALERT_STATUS_VAL,
	PASS_HDL_ALERT_STATUS_NTF_CFG,
	PASS_HDL_RINGER_SETTING_CHAR,
	PASS_HDL_RINGER_SETTING_VAL,
	PASS_HDL_RINGER_SETTING_NTF_CFG,
	PASS_HDL_RINGER_CP_CHAR,
	PASS_HDL_RINGER_CP_VAL,
	#endif /* #if (PRF_SEL_PASS) */
	
	#if (PRF_SEL_RSCS)
	/* Running Speed and Cadence Service */
	RSCS_HDL_SVC,
	RSCS_HDL_RSC_MEAS_CHAR,
	RSCS_HDL_RSC_MEAS_VAL,
	RSCS_HDL_RSC_MEAS_NTF_CFG,
	RSCS_HDL_RSC_FEATURE_CHAR,
	RSCS_HDL_RSC_FEATURE_VAL,
	RSCS_HDL_SENSOR_LOC_CHAR,
	RSCS_HDL_SENSOR_LOC_VAL,
	RSCS_HDL_SC_CP_CHAR,
	RSCS_HDL_SC_CP_VAL,
	RSCS_HDL_SC_CP_IND_CFG,
	#endif /* #if (PRF_SEL_RSCS) */

	#ifdef USE_SAMPLE_PROFILE
	/* Sample Custom Service */
	SCS_HDL_SVC,
	SCS_HDL_NOTIFY_CHAR,
	SCS_HDL_NOTIFY_VAL,
	SCS_HDL_NOTIFY_CFG,
	SCS_HDL_IND_CHAR,
	SCS_HDL_IND_VAL,
	SCS_HDL_IND_CFG,
	SCS_HDL_INTERVAL_CHAR,
	SCS_HDL_INTERVAL_VAL,
	SCS_HDL_NOTIFY_LEN_CHAR,
	SCS_HDL_NOTIFY_LEN_VAL,
	SCS_HDL_IND_LEN_CHAR,
	SCS_HDL_IND_LEN_VAL,
	#endif /* #ifdef USE_SAMPLE_PROFILE */

#if 1//Genral Purpose Communication(VUART)
#ifdef USE_VUART_PROFILE
	/* VUART Service */
	VUART_HDL_SVC,
	VUART_HDL_INDICATION_CHAR,
	VUART_HDL_INDICATION_VAL,
	VUART_HDL_INDICATION_CFG,
	VUART_HDL_WRITE_CHAR,
	VUART_HDL_WRITE_VAL,
#endif /* #ifdef USE_VUART_PROFILE */
#endif

	DB_HDL_MAX
};

#endif /* _DB_HANDLE_H_ */
